.. _rdflib.parser: Parser


=============
Parser
=============

.. automodule:: rdflib.parser
.. :noindex:
.. autofunction:: rdflib.parser.create_input_source

.. autoclass:: rdflib.parser.Parser
    :members:

.. autoclass:: rdflib.parser.InputSource
    :members:

.. autoclass:: rdflib.parser.StringInputSource
    :members:

.. autoclass:: rdflib.parser.URLInputSource
    :members:

.. autoclass:: rdflib.parser.FileInputSource
    :members:

